@@ -1,8 +1,16 @@
-import urllib
+try:
+    # Python3 case
+    from urllib.parse import urlencode
+    from urllib.request import urlopen
+except ImportError:
+    # Python2 case
+    from urllib import urlencode
+    from urllib2 import urlopen
+
 from datetime import datetime
 from xml.dom.minidom import parseString
 
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 
 API_URL='http://www.ofxhome.com/api.php'
 
@@ -29,7 +37,7 @@ class OFXHome:
 
         See also: OFXHome.search()
         """
-        return search()
+        return OFXHome.search()
 
     @staticmethod
     def search(name=None):
@@ -70,8 +78,8 @@ def _text(parent,name):
     return ''.join(rc)
 
 def _xml_request(params=None):
-    encoded = urllib.urlencode(params)
-    xml = urllib.urlopen("%s?%s" % (API_URL,encoded)).read()
+    encoded = urlencode(params)
+    xml = urlopen("%s?%s" % (API_URL,encoded)).read()
     return xml
 
 #---------------------------------------------
@@ -86,7 +94,9 @@ class InstitutionList:
 
     @staticmethod
     def from_file(file):
-        return InstitutionList(open(file,'r').read())
+        with open(file, 'r') as f:
+            data = f.read()
+        return InstitutionList(data)
 
     def __getitem__(self,item):
         return self.items[item]
@@ -128,4 +138,6 @@ class Institution:
 
     @staticmethod
     def from_file(file):
-        return Institution(open(file,'r').read())
+        with open(file, 'r') as f:
+            data = f.read()
+        return Institution(data)
